# DeepBay

This project was created with the objective of compile Machine Learning Architectures created using Tensorflow or Keras. The architectures must be provided as a ready-to-use Plug-and-Play module that can be easily integrated into any existing project or architecture design.

## Installation

You can use pip for install this from PyPi, just use:

```
pip install deepbay
```

https://pypi.org/project/deepbay
